from __future__ import absolute_import
import logging
import os

from django import template
from django.conf import settings
from django.contrib.staticfiles import finders
from django.core.exceptions import ImproperlyConfigured
from django.utils.safestring import mark_safe

from simple_svg.exceptions import SVGNotFound

logger = logging.getLogger(__name__)
register = template.Library()


@register.simple_tag
def svg(filename, *args, **kwargs):
    SVG_DIRS = getattr(settings, "SVG_DIRS", [])

    if type(SVG_DIRS) != list:
        raise ImproperlyConfigured("SVG_DIRS setting must be a list")

    path = None

    if SVG_DIRS:
        for directory in SVG_DIRS:
            svg_path = os.path.join(
                directory, "{filename}.svg".format(filename=filename)
            )

            if os.path.isfile(svg_path):
                path = svg_path
    else:
        path = finders.find(
            os.path.join("svg", "{filename}.svg".format(filename=filename)), all=True
        )

    if not path:
        message = "SVG '{filename}.svg' not found".format(filename=filename)

        # Raise exception if DEBUG is True, else just log a warning.
        if settings.DEBUG:
            raise SVGNotFound(message)
        else:
            logger.warning(message)
            return ""

    # Sometimes path can be a list/tuple if there's more than one file found
    if isinstance(path, (list, tuple)):
        path = path[0]

    with open(path) as svg_file:
        svg = svg_file.read()

    if kwargs:
        attributes = " ".join(['{}="{}"'.format(k, v) for k, v in kwargs.items()])
        svg = svg.replace("<svg", "<svg " + attributes)

    svg = mark_safe(svg)

    return svg



import os
from django.conf import settings
from django.core.exceptions import ImproperlyConfigured
from django.template import Context, Template
from django.test.testcases import SimpleTestCase

from simple_svg.exceptions import SVGNotFound


class SVGTemplateTagTest(SimpleTestCase):
    def test_should_render_svg(self):
        svg_file = open(
            os.path.join(settings.BASE_DIR, "static", "svg", "django.svg")
        ).read()
        template = Template("{% load svg %}{% svg 'django' %}")

        self.assertEqual(svg_file, template.render(Context()))

    def test_should_support_attributes(self):
        svg_file = open(
            os.path.join(settings.BASE_DIR, "static", "svg", "django.svg")
        ).read()
        template = Template("{% load svg %}{% svg 'django' id='logo' class='large' %}")

        self.assertNotEqual(svg_file, template.render(Context()))
        self.assertIn('id="logo"', template.render(Context()))
        self.assertIn('class="large"', template.render(Context()))

    def test_when_given_invalid_file_it_should_fail_silently(self):
        template = Template("{% load svg %}{% svg 'thisdoesntexist' %}")

        self.assertEqual("", template.render(Context()))

    def test_when_debug_it_should_raise_an_error(self):
        template = Template("{% load svg %}{% svg 'thisdoesntexist' %}")

        with self.settings(DEBUG=True):
            with self.assertRaises(SVGNotFound):
                template.render(Context())

    def test_should_load_svg_from_custom_directory(self):
        with self.settings(
            SVG_DIRS=[os.path.join(settings.BASE_DIR, "static", "custom-dir")]
        ):
            svg_file = open(
                os.path.join(settings.BASE_DIR, "static", "custom-dir", "other.svg")
            ).read()
            template = Template("{% load svg %}{% svg 'other' %}")

            self.assertEqual(svg_file, template.render(Context()))

    def test_when_given_invalid_file_and_using_custom_directory_it_should_fail(
        self,
    ):  # noqa
        with self.settings(
            SVG_DIRS=[os.path.join(settings.BASE_DIR, "static", "custom-dir")]
        ):
            template = Template("{% load svg %}{% svg 'nonexistent' %}")

            self.assertEqual("", template.render(Context()))

    def test_when_SVG_DIRS_isnt_a_list_it_should_raise_an_error(self):
        with self.settings(
            SVG_DIRS=os.path.join(settings.BASE_DIR, "static", "custom-dir")
        ):
            template = Template("{% load svg %}{% svg 'other' %}")

            with self.assertRaises(ImproperlyConfigured):
                template.render(Context())



from os import chdir
from os.path import abspath, dirname, join, normpath

from setuptools import find_packages, setup

with open(join(dirname(__file__), "README.md")) as readme:
    README = readme.read()


# allow setup.py to be run from any path
chdir(normpath(abspath(dirname(__file__))))

import simple_svg  # noqa

setup(
    name="django-simple-svg",
    version=simple_svg.__version__,
    packages=find_packages(exclude=["test*"]),
    include_package_data=True,
    license=simple_svg.__license__,
    description=simple_svg.__doc__,
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/xshapira/django-simple-svg",
    author="Max Shapira",
    author_email="max@winoutt.com",
    maintainer="Max Shapira",
    maintainer_email="max@winoutt.com",
    install_requires=["Django>=1.8"],
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Environment :: Plugins",
        "Environment :: Web Environment",
        # "Framework :: Django",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.10",
        "Framework :: Django",
        "Framework :: Django :: 2.0",
        "Framework :: Django :: 3.2",
        "Framework :: Django :: 4.0",
        "Topic :: Internet :: WWW/HTTP",
        "Topic :: Internet :: WWW/HTTP :: Dynamic Content",
    ],
    test_suite="tests",
)
